@@ -13,6 +13,8 @@
 #' @param levels A length 2 character string that indicate the
 #'  factor levels for the 1's (in the first position) and the zeros
 #'  (second)
+#' @param ref_first Logical. Should the first level, which replaces
+#' 1's, be the factor reference level?
 #' @param columns A vector with the selected variable names. This
 #'  is `NULL` until computed by [prep.recipe()].
 #' @return An updated version of `recipe` with the new step
@@ -51,17 +53,21 @@ step_bin2factor <-
            role = NA,
            trained = FALSE,
            levels = c("yes", "no"),
-           columns = NULL) {
+           ref_first = TRUE,
+           columns = NULL,
+           skip = FALSE) {
     if (length(levels) != 2 | !is.character(levels))
       stop("`levels` should be a two element character string", call. = FALSE)
     add_step(
       recipe,
       step_bin2factor_new(
-        terms = check_ellipses(...),
+        terms = ellipse_check(...),
         role = role,
         trained = trained,
         levels = levels,
-        columns = columns
+        ref_first = ref_first,
+        columns = columns,
+        skip = skip
       )
     )
   }
@@ -71,14 +77,18 @@ step_bin2factor_new <-
            role = NA,
            trained = FALSE,
            levels = NULL,
-           columns = NULL) {
+           ref_first = NULL,
+           columns = NULL,
+           skip = FALSE) {
     step(
       subclass = "bin2factor",
       terms = terms,
       role = role,
       trained = trained,
       levels = levels,
-      columns = columns
+      ref_first = ref_first,
+      columns = columns,
+      skip = skip
     )
   }
 
@@ -94,11 +104,14 @@ prep.step_bin2factor <- function(x, training, info = NULL, ...) {
     role = x$role,
     trained = TRUE,
     levels = x$levels,
-    columns = col_names
+    ref_first = x$ref_first,
+    columns = col_names,
+    skip = x$skip
   )
 }
 
 bake.step_bin2factor <- function(object, newdata, ...) {
+  levs <- if (object$ref_first) object$levels else rev(object$levels)
   for (i in seq_along(object$columns))
     newdata[, object$columns[i]] <-
       factor(ifelse(
@@ -106,7 +119,7 @@ bake.step_bin2factor <- function(object, newdata, ...) {
         object$levels[1],
         object$levels[2]
       ),
-      levels = object$levels)
+      levels = levs)
   newdata
 }
 
