@@ -107,6 +107,8 @@ bs_wrapper <- function(x, args) {
 #' @export
 prep.step_bs <- function(x, training, info = NULL, ...) {
   col_names <- terms_select(x$terms, info = info)
+  check_type(training[, col_names])
+
   obj <- lapply(training[, col_names], bs_wrapper, x$options)
   for (i in seq(along = col_names))
     attr(obj[[i]], "var") <- col_names[i]
@@ -141,7 +143,7 @@ bake.step_bs <- function(object, newdata, ...) {
     strt <- max(cols) + 1
     newdata[, orig_var] <- NULL
   }
-  newdata <- cbind(newdata, as_tibble(bs_values))
+  newdata <- bind_cols(newdata, as_tibble(bs_values))
   if (!is_tibble(newdata))
     newdata <- as_tibble(newdata)
   newdata
