@@ -71,17 +71,19 @@ step_corr <- function(recipe,
                       threshold = 0.9,
                       use = "pairwise.complete.obs",
                       method = "pearson",
-                      removals = NULL) {
+                      removals = NULL,
+                      skip = FALSE) {
   add_step(
     recipe,
     step_corr_new(
-      terms = check_ellipses(...),
+      terms = ellipse_check(...),
       role = role,
       trained = trained,
       threshold = threshold,
       use = use,
       method = method,
-      removals = removals
+      removals = removals,
+      skip = skip
     )
   )
 }
@@ -94,7 +96,8 @@ step_corr_new <-
     threshold = NULL,
     use = NULL,
     method = NULL,
-    removals = NULL
+    removals = NULL,
+    skip = FALSE
   ) {
     step(
       subclass = "corr",
@@ -104,13 +107,16 @@ step_corr_new <-
       threshold = threshold,
       use = use,
       method = method,
-      removals = removals
+      removals = removals,
+      skip = skip
     )
   }
 
 #' @export
 prep.step_corr <- function(x, training, info = NULL, ...) {
   col_names <- terms_select(x$terms, info = info)
+  check_type(training[, col_names])
+
   filter <- corr_filter(
     x = training[, col_names],
     cutoff = x$threshold,
@@ -125,7 +131,8 @@ prep.step_corr <- function(x, training, info = NULL, ...) {
     threshold = x$threshold,
     use = x$use,
     method = x$method,
-    removals = filter
+    removals = filter,
+    skip = x$skip
   )
 }
 
