@@ -128,6 +128,8 @@ step_depth_new <-
 prep.step_depth <- function(x, training, info = NULL, ...) {
   class_var <- x$class[1]
   x_names <- terms_select(x$terms, info = info)
+  check_type(training[, x_names])
+
   x_dat <-
     split(training[, x_names], getElement(training, class_var))
   x_dat <- lapply(x_dat, as.matrix)
@@ -171,7 +173,7 @@ bake.step_depth <- function(object, newdata, ...) {
   )
   res <- as_tibble(res)
   colnames(res) <- paste0("depth_", colnames(res))
-  res <- cbind(newdata, res)
+  res <- bind_cols(newdata, res)
   if (!is_tibble(res))
     res <- as_tibble(res)
   res
