@@ -98,17 +98,19 @@ step_isomap <-
            num  = 5,
            options = list(knn = 50, .mute = c("message", "output")),
            res = NULL,
-           prefix = "Isomap") {
+           prefix = "Isomap",
+           skip = FALSE) {
     add_step(
       recipe,
       step_isomap_new(
-        terms = check_ellipses(...),
+        terms = ellipse_check(...),
         role = role,
         trained = trained,
         num = num,
         options = options,
         res = res,
-        prefix = prefix
+        prefix = prefix,
+        skip = skip
       )
     )
   }
@@ -120,7 +122,8 @@ step_isomap_new <-
            num  = NULL,
            options = NULL,
            res = NULL,
-           prefix = "isomap") {
+           prefix = "isomap",
+           skip = FALSE) {
     step(
       subclass = "isomap",
       terms = terms,
@@ -129,7 +132,8 @@ step_isomap_new <-
       num = num,
       options = options,
       res = res,
-      prefix = prefix
+      prefix = prefix,
+      skip = skip
     )
   }
 
@@ -137,6 +141,7 @@ step_isomap_new <-
 #' @export
 prep.step_isomap <- function(x, training, info = NULL, ...) {
   col_names <- terms_select(x$terms, info = info)
+  check_type(training[, col_names])
 
   x$num <- min(x$num, ncol(training))
   x$options$knn <- min(x$options$knn, nrow(training))
@@ -157,7 +162,8 @@ prep.step_isomap <- function(x, training, info = NULL, ...) {
     num = x$num,
     options = x$options,
     res = imap,
-    prefix = x$prefix
+    prefix = x$prefix,
+    skip = x$skip
   )
 }
 
@@ -170,7 +176,7 @@ bake.step_isomap <- function(object, newdata, ...) {
       )@data
   comps <- comps[, 1:object$num, drop = FALSE]
   colnames(comps) <- names0(ncol(comps), object$prefix)
-  newdata <- cbind(newdata, as_tibble(comps))
+  newdata <- bind_cols(newdata, as_tibble(comps))
   newdata <-
     newdata[, !(colnames(newdata) %in% isomap_vars), drop = FALSE]
   if (!is_tibble(newdata))
