@@ -4,11 +4,12 @@
 #'   will apply the rectified linear or softplus transformations to numeric
 #'   data. The transformed data is added as new columns to the data matrix.
 #'
+#' @inheritParams step_center
 #' @param recipe A recipe object. The step will be added to the sequence of
 #'   operations for this recipe.
 #' @param ... One or more selector functions to choose which variables are
 #'   affected by the step. See [selections()] for more details.
-#' @param role Not used by this step since no new variables are created.
+#' @param role Defaults to "predictor".
 #' @param trained A logical to indicate if the quantities for preprocessing
 #'   have been estimated.
 #' @param shift A numeric value dictating a translation to apply to the data.
@@ -19,10 +20,10 @@
 #' @param prefix A prefix for generated column names, default to "right_relu_"
 #'   when right hinge transformation and "left_relu_" for reversed/left hinge
 #'   transformations.
-#'
 #' @return An updated version of `recipe` with the
 #'   new step added to the sequence of existing steps (if any).
 #' @export
+#' @rdname step_relu
 #'
 #' @details The rectified linear transformation is calculated as
 #'   \deqn{max(0, x - c)} and is also known as the ReLu or right hinge function.
@@ -34,7 +35,7 @@
 #'
 #' @section Connection to MARS:
 #'
-#' The rectified linear transformation is used in the Multivariate Adaptive
+#' The rectified linear transformation is used in Multivariate Adaptive
 #' Regression Splines as a basis function to fit piecewise linear functions to
 #' data in a strategy similar to that employeed in tree based models. The
 #' transformation is a popular choice as an activation function in many
@@ -69,7 +70,8 @@ step_relu <-
            shift = 0,
            reverse = FALSE,
            smooth = FALSE,
-           prefix = "right_relu_") {
+           prefix = "right_relu_",
+           skip = FALSE) {
     if (!is.numeric(shift))
       stop("Shift argument must be a numeric value.", call. = FALSE)
     if (!is.logical(reverse))
@@ -81,13 +83,14 @@ step_relu <-
     add_step(
       recipe,
       step_relu_new(
-        terms = check_ellipses(...),
+        terms = ellipse_check(...),
         role = role,
         trained = trained,
         shift = shift,
         reverse = reverse,
         smooth = smooth,
-        prefix = prefix
+        prefix = prefix,
+        skip = skip
       )
     )
   }
@@ -99,7 +102,8 @@ step_relu_new <-
            shift = 0,
            reverse = FALSE,
            smooth = FALSE,
-           prefix = "right_relu_") {
+           prefix = "right_relu_",
+           skip = FALSE) {
     step(
       subclass = "relu",
       terms = terms,
@@ -108,31 +112,45 @@ step_relu_new <-
       shift = shift,
       reverse = reverse,
       smooth = smooth,
-      prefix = prefix
+      prefix = prefix,
+      skip = skip
     )
   }
 
+#' @export
 prep.step_relu <- function(x, training, info = NULL, ...) {
+  x$columns <- terms_select(x$terms, info = info)
+  check_type(training[, x$columns])
+
   x$trained <- TRUE
   x
 }
 
 #' @importFrom dplyr select_vars tbl_vars
 #' @importFrom rlang lang sym
+#' @export
 bake.step_relu <- function(object, newdata, ...) {
-  col_names <- select_vars(tbl_vars(newdata), !!!object$terms)
-
   make_relu_call <- function(col) {
     lang("relu", sym(col), object$shift, object$reverse, object$smooth)
   }
-
-  names(col_names) <- paste0(object$prefix, col_names)
-  exprs <- purrr::map(col_names, make_relu_call)
-
+  exprs <- purrr::map(object$columns, make_relu_call)
+  names(exprs) <- paste0(object$prefix, object$columns)
   dplyr::mutate(newdata, !!!exprs)
 }
 
 
+print.step_relu <-
+  function(x, width = max(20, options()$width - 30), ...) {
+    cat("Adding relu transform for ", sep = "")
+    cat(format_selectors(x$terms, wdth = width))
+    if (x$trained)
+      cat(" [trained]\n")
+    else
+      cat("\n")
+    invisible(x)
+}
+
+
 relu <- function(x, shift = 0, reverse = FALSE, smooth = FALSE) {
   if (!is.numeric(x))
     stop("step_relu can only be applied to numeric data.", call. = FALSE)
@@ -150,3 +168,12 @@ relu <- function(x, shift = 0, reverse = FALSE, smooth = FALSE) {
   }
   out
 }
+
+#' @rdname step_relu
+#' @param x A `step_relu` object.
+tidy.step_relu <- function(x, ...) {
+  out <- simple_terms(x, ...)
+  out$shift <- x$shift
+  out$reverse <- x$reverse
+  out
+}
