@@ -36,3 +36,12 @@ test_that('printing', {
   expect_output(prep(rec2, training = covers, verbose = TRUE))
 })
 
+
+test_that('choose reference level', {
+  rec4 <- rec %>% step_bin2factor(rocks, ref_first = FALSE)
+  rec4 <- prep(rec4, training = covers)
+  res4 <- bake(rec4, newdata = covers)
+  expect_true(all(res4$rocks[res4$more_rocks == 1] == "yes"))
+  expect_true(all(res4$rocks[res4$more_rocks == 0] == "no"))
+  expect_true(levels(res4$rocks)[1] == "no")
+})
