@@ -7,9 +7,9 @@ test_that('simple skip', {
     step_log(Sepal.Length, skip = TRUE) %>%
     step_dummy(Species) %>%
     step_center(all_predictors())
-  
+
   prepped_1 <- prep(rec_1, training = iris, retain = TRUE)
-  
+
   juiced_1 <- juice(prepped_1)
   baked_1  <- bake(prepped_1, newdata = iris)
 
@@ -17,7 +17,7 @@ test_that('simple skip', {
   expect_equal(juiced_1$Sepal.Length, log(iris$Sepal.Length))
 
   prepped_2 <- prep(rec_1, training = iris, retain = FALSE)
-  
+
   baked_2  <- bake(prepped_2, newdata = iris[, -1])
   baked_3  <- bake(prepped_2, newdata = iris)
   expect_false(
@@ -27,13 +27,15 @@ test_that('simple skip', {
   )
   expect_equal(log(baked_1$Sepal.Length), juiced_1$Sepal.Length)
   expect_equal(setdiff(names(baked_1), names(baked_2)), "Sepal.Length")
-  
+
   expect_warning(prep(rec_1, training = iris, retain = FALSE))
 })
 
 
 test_that('check existing steps for `skip` arg', {
   step_check <- ls("package:recipes", pattern = "(^step_)|(^check_)")
+  # This one is not an operation
+  step_check <- step_check[step_check != "check_type"]
   has_skip_arg <- function(x) {
     x_code <- getFromNamespace(x, "recipes")
     x_args <- names(formals(x_code))
@@ -42,7 +44,7 @@ test_that('check existing steps for `skip` arg', {
   has_skip <- vapply(step_check, has_skip_arg, logical(1))
   if(any(!has_skip))
     print(names(has_skip)[!has_skip])
-  
+
   for(i in names(has_skip))
     expect_true(has_skip[i])
 })
