@@ -22,6 +22,25 @@ test_that('spatial sign', {
   expect_equal(sp_sign_pred, x)
 })
 
+test_that('Missing values', {
+  sp_sign <- rec %>%
+    step_spatialsign(carbon, hydrogen)
+  
+  sp_sign_trained <- prep(sp_sign, training = biomass, verbose = FALSE)
+  
+  with_na <- head(biomass)
+  with_na$carbon[1] <- NA
+  with_na$hydrogen[2] <- NA  
+  
+  sp_sign_pred <- bake(sp_sign_trained, newdata = with_na)
+  sp_sign_pred <- as.matrix(sp_sign_pred)[, c("carbon", "hydrogen")]
+  
+  x <- as.matrix(with_na[, 3:4])
+  x <- t(apply(x, 1, function(x) x/sqrt(sum(x^2, na.rm = TRUE))))
+  
+  expect_equivalent(sp_sign_pred, x)
+})
+
 
 test_that('printing', {
   sp_sign <- rec %>%
